[gnome-sound-recorder] record.js: improve default filename as suggested by Garrett LaSage



commit 9ed56cbf209e835fb4bd7edbaca7ef46729c0e8f
Author: Meg Ford <meg387 gmail com>
Date:   Sat Dec 14 18:56:35 2013 -0600

    record.js: improve default filename as suggested by Garrett LaSage

 src/main.js   |    2 +-
 src/record.js |    6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/main.js b/src/main.js
index b0e075f..a48a11e 100644
--- a/src/main.js
+++ b/src/main.js
@@ -116,7 +116,7 @@ const Application = new Lang.Class({
         aboutDialog.authors = [ 'Meg Ford <megford gnome org>' ];
         aboutDialog.translator_credits = _("translator-credits");
         aboutDialog.program_name = _("Sound Recorder");
-        aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + 
String.fromCharCode(0x2013) + 'Meg Ford.';
+        aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + 
String.fromCharCode(0x2013) + 'Meg Ford';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
         aboutDialog.version = '3.11.1';
         aboutDialog.website = 'http://live.gnome.org/GnomeSoundRecorder';
diff --git a/src/record.js b/src/record.js
index 378cd19..3c4b14a 100644
--- a/src/record.js
+++ b/src/record.js
@@ -282,9 +282,9 @@ const BuildFileName = new Lang.Class({
     buildInitialFilename: function() {
         let fileExtensionName = MainWindow.audioProfile.fileExtensionReturner();
         let dir = this.buildPath();
-        /* Translators: "Recording" here is the beginning of the default name assigned to a file created
-            by the application (for example, "Recording 2013-10-05 13:25:21.ogg").*/
-        let prefix = _("Recording"); 
+        /* Translators: "Audio from" is the beginning of the default name assigned to a file created
+            by the application (for example, "Audio from 2013-10-05 13:25:21.ogg").*/
+        let prefix = _("Audio from"); 
         this.dateTime = GLib.DateTime.new_now_local();
         let dateTimeString = this.dateTime.format(" %Y-%m-%d %H:%M:%S");                   
         dir.push(prefix + dateTimeString + fileExtensionName);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]